==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getwertvbextfilter.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getwertvbextfilter//
create function getwertvbextfilter(wid integer, von datetime(6), bis datetime(6),
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(20000)
deterministic
sql security invoker
begin
  declare wt varchar(30);
  select wtab from werteindizes, teststepdetails, einheiten
      where werteindizes.ID=wid and teststepdetailsID=teststepdetails.ID
        and einheitID=einheiten.ID
      into wt;
  case wt
    when 'bwerte' then return getbwertvbz(wid, von, bis, mode, zvon, zbis); 
    when 'swerte' then return getswertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'twerte' then return gettwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'cwerte' then return getcwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'pwerte' then return getpwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    else               return getzwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
  end case;
end//

GRANT EXECUTE on FUNCTION getwertvbextfilter to logginglesen@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getwertvbextfilter.sql <==
-- getwertvbextfilter.sql
--
-- function getwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- mode: aggregation function
-- zvon: time from
-- zbis: time to
-- wtf: set of weekdays
-- vg1: comparevalue 1
-- wf1: comparefunction 1
-- m2: OR|AND
-- vg2: comparevalue 2
-- wf2: comparefunction 2
-- m3: OR|AND
-- vg3: comparevalue 3
-- wf3: comparefunction 3
-- m4: OR|AND
-- vg4: comparevalue 4
-- wf4: comparefunction 4
-- return: aggragated value with extended filter

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getwertvbextfilter//
create function getwertvbextfilter(wid integer, von datetime(6), bis datetime(6),
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250))
                  returns varchar(20000)
deterministic
sql security invoker
begin
  declare wt varchar(30);
  select wtab into wt from werteindizes, teststepdetails, einheiten
      where werteindizes.ID = wid and teststepdetailsID = teststepdetails.ID
        and einheitID = einheiten.ID;
  case wt
    when 'bwerte' then return getbwertvbz(wid, von, bis, mode, zvon, zbis); 
    when 'swerte' then return getswertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'twerte' then return gettwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'cwerte' then return getcwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    when 'pwerte' then return getpwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
    else               return getzwertvbextfilter(wid, von, bis, mode, zvon, zbis, wtf,
                                vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4);
  end case;
end//

GRANT EXECUTE on FUNCTION getwertvbextfilter to logginglesen@'localhost'//
